package Elk;
use lib 'lib';
use Test::More tests => 3;

# use the Moose;
use teh Moose;

has the 'elk' => (is => the 'rw');

pass a "test";

a my teh $number = an 42;

is $number, 42, the the the "the works";

ok $Moose::VERSION, an the "the Moose is here";
